# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegionGrowingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkNeighborhoodConnectedImageFilterPython
else:
    import _itkNeighborhoodConnectedImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkNeighborhoodConnectedImageFilterIF2IF2_New():
    return itkNeighborhoodConnectedImageFilterIF2IF2.New()

class itkNeighborhoodConnectedImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterIF2IF2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterIF2IF2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize2"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterIF2IF2

        Create a new object of the class itkNeighborhoodConnectedImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterIF2IF2 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF2IF2_swigregister(itkNeighborhoodConnectedImageFilterIF2IF2)

def itkNeighborhoodConnectedImageFilterIF3IF3_New():
    return itkNeighborhoodConnectedImageFilterIF3IF3.New()

class itkNeighborhoodConnectedImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterIF3IF3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterIF3IF3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize3"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterIF3IF3

        Create a new object of the class itkNeighborhoodConnectedImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterIF3IF3 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIF3IF3_swigregister(itkNeighborhoodConnectedImageFilterIF3IF3)

def itkNeighborhoodConnectedImageFilterISS2ISS2_New():
    return itkNeighborhoodConnectedImageFilterISS2ISS2.New()

class itkNeighborhoodConnectedImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterISS2ISS2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterISS2ISS2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize2"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterISS2ISS2

        Create a new object of the class itkNeighborhoodConnectedImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterISS2ISS2 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS2ISS2_swigregister(itkNeighborhoodConnectedImageFilterISS2ISS2)

def itkNeighborhoodConnectedImageFilterISS3ISS3_New():
    return itkNeighborhoodConnectedImageFilterISS3ISS3.New()

class itkNeighborhoodConnectedImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterISS3ISS3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterISS3ISS3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize3"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterISS3ISS3

        Create a new object of the class itkNeighborhoodConnectedImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterISS3ISS3 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterISS3ISS3_swigregister(itkNeighborhoodConnectedImageFilterISS3ISS3)

def itkNeighborhoodConnectedImageFilterIUC2IUC2_New():
    return itkNeighborhoodConnectedImageFilterIUC2IUC2.New()

class itkNeighborhoodConnectedImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize2

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize2"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterIUC2IUC2

        Create a new object of the class itkNeighborhoodConnectedImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterIUC2IUC2 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC2IUC2_swigregister(itkNeighborhoodConnectedImageFilterIUC2IUC2)

def itkNeighborhoodConnectedImageFilterIUC3IUC3_New():
    return itkNeighborhoodConnectedImageFilterIUC3IUC3.New()

class itkNeighborhoodConnectedImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkNeighborhoodConnectedImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNeighborhoodConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNeighborhoodConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_ClearSeeds(self)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_AddSeed(self, seed)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_GetUpper(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_GetReplaceValue(self)

    def SetRadius(self, _arg):
        r"""
        SetRadius(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SetRadius(self, _arg)

    def GetRadius(self):
        r"""GetRadius(self) -> itkSize3"""
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_GetRadius(self)
    InputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_InputEqualityComparableCheck
    
    OutputEqualityComparableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_OutputEqualityComparableCheck
    
    SameDimensionCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_SameDimensionCheck
    
    InputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkNeighborhoodConnectedImageFilterPython.delete_itkNeighborhoodConnectedImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNeighborhoodConnectedImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNeighborhoodConnectedImageFilterIUC3IUC3

        Create a new object of the class itkNeighborhoodConnectedImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNeighborhoodConnectedImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNeighborhoodConnectedImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNeighborhoodConnectedImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNeighborhoodConnectedImageFilterIUC3IUC3 in _itkNeighborhoodConnectedImageFilterPython:
_itkNeighborhoodConnectedImageFilterPython.itkNeighborhoodConnectedImageFilterIUC3IUC3_swigregister(itkNeighborhoodConnectedImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def neighborhood_connected_image_filter(*args: itkt.ImageLike,  seed: Sequence[int]=..., lower: int=..., upper: int=..., replace_value: int=..., radius: Sequence[int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for NeighborhoodConnectedImageFilter"""
    import itk

    kwarg_typehints = { 'seed':seed,'lower':lower,'upper':upper,'replace_value':replace_value,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.NeighborhoodConnectedImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def neighborhood_connected_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegionGrowing.NeighborhoodConnectedImageFilter
    neighborhood_connected_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    neighborhood_connected_image_filter.__doc__ = filter_object.__doc__



